"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.claim
from eis.claim.model.claim_class import ClaimClass
from eis.claim.model.payout_details_class import PayoutDetailsClass
from eis.claim.model.regress_details_class import RegressDetailsClass
from eis.claim.model.reserve_details_class import ReserveDetailsClass
globals()['ClaimClass'] = ClaimClass
globals()['PayoutDetailsClass'] = PayoutDetailsClass
globals()['RegressDetailsClass'] = RegressDetailsClass
globals()['ReserveDetailsClass'] = ReserveDetailsClass
from eis.claim.model.regulation_item_class import RegulationItemClass


class TestRegulationItemClass(unittest.TestCase):
    """RegulationItemClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRegulationItemClass(self):
        """Test RegulationItemClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RegulationItemClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
